==> jc-1.4.0.tar.gz: java/util/Collections__24UnmodifiableSortedMap.h <==
// class java.util.Collections$UnmodifiableSortedMap

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 275fe999cef47e90 java_util_Collections__24UnmodifiableMap
// @dep_class a1c63c90c3d492fc java_util_Collections__24UnmodifiableSortedMap

// header file dependencies
// @dep_header java_util_Collections__24UnmodifiableMap

#include "java/util/Collections__24UnmodifiableMap.h"

#ifndef _JC_java_util_Collections__24UnmodifiableSortedMap_H_
#define _JC_java_util_Collections__24UnmodifiableSortedMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Comparator$object;
struct _jc_java_util_SortedMap$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableSortedMap$sub_refs	_jc_java_util_Collections__24UnmodifiableSortedMap$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedMap$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableSortedMap$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedMap$refs	_jc_java_util_Collections__24UnmodifiableSortedMap$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedMap$nonrefs	_jc_java_util_Collections__24UnmodifiableSortedMap$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedMap$object	_jc_java_util_Collections__24UnmodifiableSortedMap$object;

typedef struct _jc_java_util_Collections__24UnmodifiableSortedMap$fields_struct	_jc_java_util_Collections__24UnmodifiableSortedMap$fields_struct;
typedef const struct _jc_java_util_Collections__24UnmodifiableSortedMap$vmethods	_jc_java_util_Collections__24UnmodifiableSortedMap$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableSortedMap$vtable	_jc_java_util_Collections__24UnmodifiableSortedMap$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableSortedMap$vtype	_jc_java_util_Collections__24UnmodifiableSortedMap$vtype;

// Class fields structure
struct _jc_java_util_Collections__24UnmodifiableSortedMap$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24UnmodifiableSortedMap$fields_struct _jc_java_util_Collections__24UnmodifiableSortedMap$class_fields;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableSortedMap$method$_init$b8b18dc0609f98ee(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedMap$method$comparator$685c966d9d487177(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24UnmodifiableSortedMap$method$firstKey$1d795f88ad41d60f(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *);
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedMap$method$headMap$cd1c0e4f2149ad0e(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24UnmodifiableSortedMap$method$lastKey$5e1b1339ae1f923e(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *);
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedMap$method$subMap$9075b8398fbdea53(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedMap$method$tailMap$8556654599c88ce2(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedMap$method_info$comparator$685c966d9d487177;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedMap$method_info$firstKey$1d795f88ad41d60f;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedMap$method_info$headMap$cd1c0e4f2149ad0e;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedMap$method_info$lastKey$5e1b1339ae1f923e;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedMap$method_info$subMap$9075b8398fbdea53;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedMap$method_info$tailMap$8556654599c88ce2;

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableSortedMap$vmethods {
	struct _jc_object	*(*comparator$685c966d9d487177)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *);
	struct _jc_java_lang_Object$object	*(*firstKey$1d795f88ad41d60f)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *);
	struct _jc_object	*(*headMap$cd1c0e4f2149ad0e)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*lastKey$5e1b1339ae1f923e)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *);
	struct _jc_object	*(*subMap$9075b8398fbdea53)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*tailMap$8556654599c88ce2)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableSortedMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableMap$vmethods	java_util_Collections__24UnmodifiableMap;
	_jc_java_util_Collections__24UnmodifiableSortedMap$vmethods	java_util_Collections__24UnmodifiableSortedMap;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableSortedMap$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableSortedMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableSortedMap$sub_refs {
	struct _jc_object	*sm;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableSortedMap$refs {
    _jc_java_util_Collections__24UnmodifiableSortedMap$sub_refs	java_util_Collections__24UnmodifiableSortedMap;
    _jc_java_util_Collections__24UnmodifiableMap$sub_refs	java_util_Collections__24UnmodifiableMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableSortedMap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableSortedMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableMap$sub_nonrefs	java_util_Collections__24UnmodifiableMap;
    _jc_java_util_Collections__24UnmodifiableSortedMap$sub_nonrefs	java_util_Collections__24UnmodifiableSortedMap;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableSortedMap$object {
	_jc_java_util_Collections__24UnmodifiableSortedMap$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableSortedMap$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableSortedMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableSortedMap$vtype _jc_java_util_Collections__24UnmodifiableSortedMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableSortedMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableSortedMap$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableSortedMap_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24UnmodifiableSortedMap.h <==
// class java.util.Collections$UnmodifiableSortedMap

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 275fe999cef47e90 java_util_Collections__24UnmodifiableMap
// @dep_class a1c63c90c3d492fc java_util_Collections__24UnmodifiableSortedMap

// header file dependencies
// @dep_header java_util_Collections__24UnmodifiableMap

#include "java/util/Collections__24UnmodifiableMap.h"

#ifndef _JC_java_util_Collections__24UnmodifiableSortedMap_H_
#define _JC_java_util_Collections__24UnmodifiableSortedMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Comparator$object;
struct _jc_java_util_SortedMap$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableSortedMap$sub_refs	_jc_java_util_Collections__24UnmodifiableSortedMap$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedMap$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableSortedMap$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedMap$refs	_jc_java_util_Collections__24UnmodifiableSortedMap$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedMap$nonrefs	_jc_java_util_Collections__24UnmodifiableSortedMap$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedMap$object	_jc_java_util_Collections__24UnmodifiableSortedMap$object;

typedef struct _jc_java_util_Collections__24UnmodifiableSortedMap$fields_struct	_jc_java_util_Collections__24UnmodifiableSortedMap$fields_struct;
typedef const struct _jc_java_util_Collections__24UnmodifiableSortedMap$vmethods	_jc_java_util_Collections__24UnmodifiableSortedMap$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableSortedMap$vtable	_jc_java_util_Collections__24UnmodifiableSortedMap$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableSortedMap$vtype	_jc_java_util_Collections__24UnmodifiableSortedMap$vtype;

// Class fields structure
struct _jc_java_util_Collections__24UnmodifiableSortedMap$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24UnmodifiableSortedMap$fields_struct _jc_java_util_Collections__24UnmodifiableSortedMap$class_fields;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableSortedMap$method$_init$b8b18dc0609f98ee(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedMap$method$comparator$685c966d9d487177(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24UnmodifiableSortedMap$method$firstKey$1d795f88ad41d60f(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedMap$method$headMap$cd1c0e4f2149ad0e(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24UnmodifiableSortedMap$method$lastKey$5e1b1339ae1f923e(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedMap$method$subMap$9075b8398fbdea53(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedMap$method$tailMap$8556654599c88ce2(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedMap$method_info$comparator$685c966d9d487177;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedMap$method_info$firstKey$1d795f88ad41d60f;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedMap$method_info$headMap$cd1c0e4f2149ad0e;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedMap$method_info$lastKey$5e1b1339ae1f923e;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedMap$method_info$subMap$9075b8398fbdea53;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedMap$method_info$tailMap$8556654599c88ce2;

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableSortedMap$vmethods {
	struct _jc_object	*(*comparator$685c966d9d487177)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*firstKey$1d795f88ad41d60f)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*headMap$cd1c0e4f2149ad0e)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*lastKey$5e1b1339ae1f923e)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*subMap$9075b8398fbdea53)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*tailMap$8556654599c88ce2)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedMap$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableSortedMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableMap$vmethods	java_util_Collections__24UnmodifiableMap;
	_jc_java_util_Collections__24UnmodifiableSortedMap$vmethods	java_util_Collections__24UnmodifiableSortedMap;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableSortedMap$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableSortedMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableSortedMap$sub_refs {
	struct _jc_object	*sm;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableSortedMap$refs {
    _jc_java_util_Collections__24UnmodifiableSortedMap$sub_refs	java_util_Collections__24UnmodifiableSortedMap;
    _jc_java_util_Collections__24UnmodifiableMap$sub_refs	java_util_Collections__24UnmodifiableMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableSortedMap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableSortedMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableMap$sub_nonrefs	java_util_Collections__24UnmodifiableMap;
    _jc_java_util_Collections__24UnmodifiableSortedMap$sub_nonrefs	java_util_Collections__24UnmodifiableSortedMap;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableSortedMap$object {
	_jc_java_util_Collections__24UnmodifiableSortedMap$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableSortedMap$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableSortedMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableSortedMap$vtype _jc_java_util_Collections__24UnmodifiableSortedMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableSortedMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableSortedMap$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableSortedMap_H_ */
